@@ -15,8 +15,8 @@
 # under the License.
 from oslo_log import log as logging
 
-from designate.utils import generate_uuid
 from designate.network_api import base
+from designate.utils import generate_uuid
 
 
 LOG = logging.getLogger(__name__)
@@ -28,7 +28,7 @@ ALLOCATIONS = {}
 
 def _format_floatingip(id_, address):
     return {
-        'region': u'RegionOne',
+        'region': 'RegionOne',
         'address': address,
         'id': id_
     }
